open-cravat submit

JOBS
STORE
ADMIN
System update available
Version:

Variants
Genome:
Add input files
Example: OR
Note:
Annotations Packages Additional Analysis |
Job ID | Input File | Variants | Annotators | Genome | Note | Status | Download | Delete
--- | --- | --- | --- | --- | --- | --- | --- | ---

Discover View All Update available

Packages

By Category

Most Downloaded
The most downloaded modules to date!
Newest
The newest and greatest!
Cancer Resources
Cutting edge resources for cancer research!
Clinical Relevance
Our curation of clinically-relevant resources!
Sort by
There are missing system modules which Open-CRAVAT needs.
Click this button to install them:
System updates in progress...
System configuration file:
Jobs dir:
Modules dir:
Limit the sum of input file sizes to: MB
Maximum number of concurrent jobs:
Maximum number of concurrent annotators per job:
Allow collection of CRAVAT metrics:

Lost connection to the server.
Please launch OpenCRAVAT again.
Uploading input file(s)...
Updating store information...
Choose a report type: